Documentation
¶
Overview ¶
Code generated for package frontend by go-bindata DO NOT EDIT. (@generated) sources: frontend/build/asset-manifest.json frontend/build/favicon.ico frontend/build/index.html frontend/build/logo192.png frontend/build/logo512.png frontend/build/manifest.json frontend/build/precache-manifest.ff1cd97d3ef55de680f3ca4b3fd5bec3.js frontend/build/robots.txt frontend/build/service-worker.js frontend/build/static/js/2.df3d1213.chunk.js frontend/build/static/js/2.df3d1213.chunk.js.map frontend/build/static/js/main.3cde071d.chunk.js frontend/build/static/js/main.3cde071d.chunk.js.map frontend/build/static/js/runtime-main.fca44c8b.js frontend/build/static/js/runtime-main.fca44c8b.js.map
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Asset ¶
Asset loads and returns the asset for the given name. It returns an error if the asset could not be found or could not be loaded.
func AssetDir ¶
AssetDir returns the file names below a certain directory embedded in the file by go-bindata. For example if you run go-bindata on data/... and data contains the following hierarchy:
data/
foo.txt
img/
a.png
b.png
then AssetDir("data") would return []string{"foo.txt", "img"} AssetDir("data/img") would return []string{"a.png", "b.png"} AssetDir("foo.txt") and AssetDir("notexist") would return an error AssetDir("") will return []string{"data"}.
func AssetInfo ¶
AssetInfo loads and returns the asset info for the given name. It returns an error if the asset could not be found or could not be loaded.
func MustAsset ¶
MustAsset is like Asset but panics when Asset would return an error. It simplifies safe initialization of global variables.
func RestoreAsset ¶
RestoreAsset restores an asset under the given directory
func RestoreAssets ¶
RestoreAssets restores an asset under the given directory recursively
Types ¶
This section is empty.